2024-03-01 Version: 1.1.0
- Support API ActualDeductResources.
- Support API DirectDeductResources.
- Support API ExpectDeductResources.
- Support API GetRemainResource.


2024-01-09 Version: 1.0.2
- Generated python2 2024-01-18 for IntelligentCreation.

2024-01-05 Version: 1.0.1
- Generated python2 2024-01-18 for IntelligentCreation.

2024-01-05 Version: 1.0.0
- Generated python2 2024-01-18 for IntelligentCreation.

